<?php

/**
 * @file
 *
 * Contains Webtrees support functions
 */


/**
 * Log webtrees message
 *
 * @param string $type
 * 
 * @param string $message
 */ 
function webtrees_log ($type, $message){
 switch ($type) {
  case 'emergenty':
     $severity = WATCHDOG_EMERGENCY;
     break;
  case 'alert':
     $severity = WATCHDOG_ALERT;
     break;
  case 'critical':
     $severity = WATCHDOG_CRITICAL;
     break;
  case 'error':
     $severity = WATCHDOG_ERROR;
     break;
  case 'warning':
     $severity = WATCHDOG_WARNING;
     break;
  default:
  case 'notice':
     $severity = WATCHDOG_NOTICE;
     break;
  case 'info':
     $severity = WATCHDOG_INFO;
     break;
  case 'debug':
     $severity = WATCHDOG_DEBUG;
     break;
 }
  watchdog('webtrees',$message,array(),$severity);
}


/**
 * Class webtrees_config
 *   get and put configuration settings
 */ 
class webtrees_config {
  /**
   * Default configuration settings
   */
  private static $default = array (
    'database.use_drupal'         => true,
    'database.driver'             => 'mysql',
    'database.host'               => 'localhost',
    'database.port'               => '3306',
    'database.user'               => 'webtrees',
    'database.password'           => 'password',
    'database.database'           => 'webtrees',
    'database.prefix'             => 'wt_',
    'configuration.url'           => '/webtrees/',
    'configuration.enable'        => false,
    'configuration.login'         => true,
    'configuration.use_webtrees'  => false,
    'configuration.allow_reverse' => false,
    'configuration.logging'       => false,
    'configuration.exclude'       => 'administrator',
    'role.webtrees.administrator' => 'administrator',
    'role.webtrees.manager'       => 'authenticated',
    'role.webtrees.moderator'     => 'authenticated',
    'role.webtrees.editor'        => 'authenticated',
    'role.webtrees.member'        => 'authenticated',
    'role.drupal.administrator'   => '',
    'role.drupal.manager'         => '',
    'role.drupal.moderator'       => '',
    'role.drupal.editor'          => '',
    'webtrees_user.autoaccept'    =>  false,
    'webtrees_user.comment'       => 'User added by Webtrees Drupal module',
    'webtrees_user.comment_exp'   => '',
    'webtrees_user.language'      => 'en-US',
    'webtrees_user.contactmethod' => 'messaging',
    'webtrees_user.timezone'      => 'UTC',
    'webtrees_user.verified'      => true,
    'webtrees_user.verified_by_admin' => true,
    'webtrees_user.visibleonline' => true,
    'webtrees_user.gedcom'        => 1,
    );

  /**
   * Get configuration value 
   *
   * @param string $id
   *
   * @return string
   */
  public function get ($id) {
    return variable_get('webtrees.'.$id,isset(self::$default[$id])?self::$default[$id]:'');
  }

  /**
   * Save configuration value
   *
   * $param string $id
   *
   * $param string $value 
   */
  public function set ($id, $value) {
    variable_set('webtrees.'.$id, $value);
  }
}

 
